@@ -13,8 +13,20 @@ import pilas
 from pilas.actores import Actor
 
 class Mapa(Actor):
+    """Representa una mapa de bloques rectangulares, ideal para crear escenarios de plataformas
+    y mapas.
+    """
+
 
     def __init__(self, grilla=None, x=0, y=0, filas=20, columnas=20):
+        """Inicializa el mapa.
+
+        :param grilla: La imagen a utilizar cómo grilla con los bloques del escenario.
+        :param x: Posición horizontal del mapa.
+        :param y: Posición vertical del mapa.
+        :param filas: Cantidad de filas que tendrá el mapa.
+        :param columnas: Cantidad de columnas que tendrá el mapa.
+        """
         Actor.__init__(self, 'invisible.png', x, y)
 
         self.filas = filas
@@ -40,6 +52,13 @@ class Mapa(Actor):
         return matriz_de_bloques
 
     def pintar_bloque(self, fila, columna, indice, es_bloque_solido=True):
+        """Define un bloque de la grilla.
+
+        :param fila: La fila que se definirá (comenzando desde 0).
+        :param columna: La columna que se definirá (comenzando desde 0).
+        :param indice: El número de cuadro referente a la grilla (comenzando desde 0).
+        :param es_bloque_solido: True o False para indicar si los objetos físicos deberán colisionar con este bloque.
+        """
         #self.matriz_de_bloques[fila][columna] = es_bloque_solido
         self.matriz_de_bloques[fila][columna] = es_bloque_solido
 
@@ -56,6 +75,7 @@ class Mapa(Actor):
         self.grilla.dibujarse_sobre_una_pizarra(self.superficie, x, y)
 
     def pintar_limite_de_bloques(self):
+        """Dibuja los bordes de cada bloque."""
         ancho = self.grilla.cuadro_ancho
         alto = self.grilla.cuadro_alto
 
@@ -84,7 +104,12 @@ class Mapa(Actor):
         valor limite de la busqueda. Por ejemplo, si colocamos 100 como
         limite y la funcion nos retorna 100 es porque no encontró un suelo
         a menos de 100 pixels. Este límite existe por una cuestión de
-        eficiencia."""
+        eficiencia.
+
+        :param x: Posición horizontal de referencia.
+        :param y: Posición vertical de referencia.
+        :param maximo: Cantidad máxima de pixels a leer.
+        """
 
         # TODO: se puede hacer mas eficiente el algoritmo si en lugar
         #       de recorrer desde 0 a maximo solamente se recorre dando
@@ -110,18 +135,32 @@ class Mapa(Actor):
                 if self.es_punto_solido_coordenada_mapa(x, y+distancia):
                     return distancia
 
-        except Exception as a:
+        except Exception:
             return maximo
 
         return maximo
 
     def es_bloque_solido(self, fila, columna):
+        """Indica si un determinado bloque es solido.
+
+        Los bloques sólidos se utilizan para marcar paredes y plataformas, es
+        decir que son bloques que generalmente no se pueden sobrepasar.
+
+        :param fila: La fila que se observará.
+        :param columna: La columna que se observará.
+        """
         if not 0 <= fila < self.filas or not 0 <= columna < self.columnas:
             raise Exception("La fila y columna consultadas estan fuera del area del mapa.")
 
         return self.matriz_de_bloques[fila][columna]
 
     def es_punto_solido(self, x, y):
+        """Indica si una coordenada del escenario está sobre un bloque solido.
+
+        :param x: Posición horizontal a consultar.
+        :param y: Posición vertical a consultar.
+
+        """
         # Los parametros x e y son coordenadas del escenario,
         # lo que se conoce como coordenanadas absolutas.
 
@@ -132,21 +171,39 @@ class Mapa(Actor):
         return self.es_punto_solido_coordenada_mapa(x, y)
 
     def convertir_de_coordenada_absoluta_a_coordenada_mapa(self, x, y):
+        """Toma un punto de pantalla y lo convierte a una coordenada dentro del mapa.
+
+        :param x: Coordenada horizontal de pantalla.
+        :param y: Coordenada vertical de pantalla.
+        """
         dx, dy = self.centro
         x = x + dx - self.x
         y = -y + dy + self.y
         return x, y
 
     def es_punto_solido_coordenada_mapa(self, x, y):
+        """Consulta si un punto (x, y) está señalando un bloque sólido.
+
+        :param x: Coordenada horizontal.
+        :param y: Coordenada vertical.
+        """
         fila = self.obtener_numero_de_fila(y)
         columna = self.obtener_numero_de_columna(x)
         return self.es_bloque_solido(fila, columna)
 
     def obtener_numero_de_fila(self, y):
+        """Retorna el número de fila correspondiente a una coordenada vertical.
+
+        :param y: La coordenada vertical (relativa al mapa, no a la pantalla).
+        """
         # 'y' tiene que ser una coordenada del mapa
         return self._convertir_en_int(y / self.grilla.cuadro_alto)
 
     def obtener_numero_de_columna(self, x):
+        """Retorna el número de columna correspondiente a una coordenada horizontal.
+
+        :param x: La coordenada horizontal (relativa al mapa, no a la pantalla).
+        """
         # 'x'tiene que ser una coordenada del mapa
         return self._convertir_en_int(x / self.grilla.cuadro_ancho)
 
