@@ -45,6 +45,14 @@ def mostrar_puntero_del_mouse():
     """Muestra el puntero del mouse."""
     pilas.mundo.motor.mostrar_puntero_del_mouse()
 
+def modo_pantalla_completa():
+    """Pone Pilas a pantalla completa"""
+    pilas.mundo.motor.ventana.canvas.pantalla_completa()
+
+def modo_ventana():
+    """Pone Pilas en modo ventana"""
+    pilas.mundo.motor.ventana.canvas.pantalla_modo_ventana()
+
 def definir_modos(*k, **kv):
     """Define los modos de depuración."""
     pilas.mundo.motor.canvas.depurador.definir_modos(*k, **kv)
