@@ -8,13 +8,13 @@ def crear_mapa():
     mapa = pilas.actores.Mapa(filas=15, columnas=20)
 
     # Plataforma superior (la que esta en medio de la pantalla)
-    mapa.pintar_bloque(10, 6, 0)
-    mapa.pintar_bloque(10, 7, 1)
-    mapa.pintar_bloque(10, 8, 1)
-    mapa.pintar_bloque(10, 9, 1)
-    mapa.pintar_bloque(10, 10, 1)
-    mapa.pintar_bloque(10, 11, 1)
-    mapa.pintar_bloque(10, 12, 2)
+    mapa.pintar_bloque(9, 6, 0)
+    mapa.pintar_bloque(9, 7, 1)
+    mapa.pintar_bloque(9, 8, 1)
+    mapa.pintar_bloque(9, 9, 1)
+    mapa.pintar_bloque(9, 10, 1)
+    mapa.pintar_bloque(9, 11, 1)
+    mapa.pintar_bloque(9, 12, 2)
 
     # Plataforma pequeña, mas abajo que la anterior.
     mapa.pintar_bloque(12, 12, 0)
@@ -27,6 +27,16 @@ def crear_mapa():
     mapa.pintar_bloque(13, 14, 9, False)
     mapa.pintar_bloque(13, 15, 10, False)
 
+    mapa.pintar_bloque(13, 0, 7, True)
+    mapa.pintar_bloque(12, 0, 7, True)
+    mapa.pintar_bloque(11, 0, 7, True)
+    mapa.pintar_bloque(10, 0, 7, True)
+
+    mapa.pintar_bloque(13, 19, 7, True)
+    mapa.pintar_bloque(12, 19, 7, True)
+    mapa.pintar_bloque(11, 19, 7, True)
+    mapa.pintar_bloque(10, 19, 7, True)
+
     # Pinta todo el suelo
     for columna in range(0, 20):
         mapa.pintar_bloque(14, columna, 1)
@@ -37,6 +47,7 @@ pilas.iniciar()
 
 mapa = crear_mapa()
 martian = pilas.actores.Martian(mapa)
+martian.aprender(pilas.habilidades.SiempreEnElCentro)
 
 pilas.avisar("Usa los direccionales para controlar al personaje.")
 pilas.ejecutar()
